Rebrand to flashprog and update URLs

Mostly automated `sed` work. As of now, URLs to the old wiki are broken
either way, so changing them shouldn't hurt. Other URLs (e.g. to mailing
list archives) were hopefully filtered correctly.

Change-Id: I9d43bfd0e675eff2fcbad05f304b9ce9f5006b08
Signed-off-by: Nico Huber <nico.h@gmx.de>
Reviewed-on: https://review.sourcearcade.org/c/flashrom-stable/+/21
diff --git a/board_enable.c b/board_enable.c
index 76fbe8a..dc0dda2 100644
--- a/board_enable.c
+++ b/board_enable.c
@@ -622,8 +622,8 @@
 			/* The data sheet contradicts itself about max size. */
 			max_rom_decode.parallel = 1024 * 1024;
 			msg_pinfo("IT8705F with very unusual settings.\n"
-				  "Please send the output of \"flashrom -V -p internal\" to\n"
-				  "flashrom-stable@flashrom.org with \"IT8705: your board name: flashrom -V\"\n"
+				  "Please send the output of \"flashprog -V -p internal\" to\n"
+				  "flashprog@flashprog.org with \"IT8705: your board name: flashprog -V\"\n"
 				  "as the subject to help us finish support for your Super I/O. Thanks.\n");
 			ret = 1;
 		} else if (tmp & 0x08) {
@@ -2317,7 +2317,7 @@
 
 /*
  * Below is the list of boards which need a special "board enable" code in
  * flashrom before their ROM chip can be accessed/written to.
  *
  * NOTE: Please add boards that _don't_ need such enables or don't work yet
  *       to the respective tables in print.c. Thanks!
@@ -2553,7 +2553,7 @@
 		const struct board_match *b = &board_matches[i];
 		if (b->vendor_name == NULL || b->board_name == NULL) {
 			msg_gerr("ERROR: Board enable #%d does not define a vendor and board name.\n"
-				 "Please report a bug at flashrom-stable@flashrom.org\n", i);
+				 "Please report a bug at flashprog@flashprog.org\n", i);
 			ret = 1;
 			continue;
 		}
@@ -2562,7 +2562,7 @@
 		    ((b->lb_vendor == NULL) ^ (b->lb_part == NULL)) ||
 		    (b->max_rom_decode_parallel == 0 && b->enable == NULL)) {
 			msg_gerr("ERROR: Board enable for %s %s is misdefined.\n"
-				 "Please report a bug at flashrom-stable@flashrom.org\n",
+				 "Please report a bug at flashprog@flashprog.org\n",
 				 b->vendor_name, b->board_name);
 			ret = 1;
 		}
@@ -2631,7 +2631,7 @@
 		if (partmatch) {
 			/* More than one entry has a matching name. */
 			msg_perr("Board name \"%s\":\"%s\" and PCI IDs matched more than one board enable\n"
-				 "entry. Please report a bug at flashrom-stable@flashrom.org\n", vendor, model);
+				 "entry. Please report a bug at flashprog@flashprog.org\n", vendor, model);
 			return NULL;
 		}
 		partmatch = board;
@@ -2714,7 +2714,7 @@
 		return 1;
 	}
 	msg_pwarn("NOTE: Running an untested board enable procedure.\n"
-		  "Please report success/failure to flashrom-stable@flashrom.org.\n");
+		  "Please report success/failure to flashprog@flashprog.org.\n");
 	return 0;
 }
@@ -2317,7 +2317,7 @@
 /*
  * Below is the list of boards which need a special "board enable" code in
- * flashrom before their ROM chip can be accessed/written to.
+ * flashprog before their ROM chip can be accessed/written to.
  *
  * NOTE: Please add boards that _don't_ need such enables or don't work yet